California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 036 - ALLOWS FELONY CHARGES AND INCREASES SENTENCES FOR CERTAIN DRUG AND THEFT CRIMES. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1462938 | YES ON PROP 36 - CALIFORNIANS FOR SAFER COMUNITIES, SPONSORED BY GOLDEN STATE COMMUNITIES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1465209 | CALIFORNIANS FOR SAFE STORES AND NEIGHBORHOODS, SPONSORED BY THE CALIFORNIA RETAILERS ASSOCIATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1468083 | COMMITTEE TO PROTECT PUBLIC SAFETY, SPONSORED BY ACTION FOR SAFETY AND JUSTICE, NO ON PROP. 36 | OPPOSE